@@ -36,6 +36,7 @@
 
 #ifdef _MSC_VER
 #  define inline _inline
+#  define snprintf _snprintf
 #endif
 
 #define SNIPPET_BUFFER_SIZE 256
@@ -359,6 +360,9 @@ normalize(grn_ctx *ctx, grn_obj *string,
     rest += character_length;
     rest_length -= character_length;
   }
+  if (current_type) {
+    current_type[0] = GRN_CHAR_NULL;
+  }
 
   if (rest_length > 0) {
     char buffer[SNIPPET_BUFFER_SIZE];
